@@ -28,9 +28,6 @@ func cmdAutocomplete(p *lang.Process) error {
 	case "set":
 		return set(p)
 
-	//case "cache-dynamic":
-	//	return cacheDynamic(p)
-
 	default:
 		p.Stdout.SetDataType(types.Null)
 		return errors.New("Not a valid mode. Please use `get` or `set`")
@@ -57,6 +54,8 @@ func get(p *lang.Process) error {
 	return err
 }
 
+var ErrEmptyAutocomplete = errors.New("empty autocomplete")
+
 func set(p *lang.Process) error {
 	p.Stdout.SetDataType(types.Null)
 
@@ -93,6 +92,10 @@ func set(p *lang.Process) error {
 		return err
 	}
 
+	if len(flags) == 0 {
+		return ErrEmptyAutocomplete
+	}
+
 	// So we don't have nil values in JSON
 	if flags[0].CacheTTL == 0 {
 		flags[0].CacheTTL = 5
