@@ -33,7 +33,7 @@ func cmdTempFile(p *lang.Process) error {
 		return err
 	}
 
-	name := consts.TempDir + hex.EncodeToString(h.Sum(nil)) + "-" + strconv.Itoa(os.Getpid()) + ext
+	name := consts.TmpDir() + hex.EncodeToString(h.Sum(nil)) + "-" + strconv.Itoa(os.Getpid()) + ext
 
 	file, err := os.Create(name)
 	if err != nil {
