@@ -3,7 +3,6 @@ package structs
 import (
 	"errors"
 	"fmt"
-	"regexp"
 	"strings"
 
 	"github.com/lmorg/murex/config/defaults"
@@ -14,8 +13,6 @@ import (
 )
 
 func init() {
-	lang.DefineFunction("alias", cmdAlias, types.Null)
-	lang.DefineFunction("!alias", cmdUnalias, types.Null)
 	lang.DefineFunction("function", cmdFunc, types.Null)
 	lang.DefineFunction("!function", cmdUnfunc, types.Null)
 	lang.DefineFunction("private", cmdPrivate, types.Null)
@@ -33,82 +30,6 @@ func init() {
 `)
 }
 
-var rxAlias = regexp.MustCompile(`^([-_.a-zA-Z0-9]+)=(.*?)$`)
-
-func cmdAlias(p *lang.Process) error {
-	if p.Parameters.Len() == 0 {
-		p.Stdout.SetDataType(types.Json)
-		b, err := json.Marshal(lang.GlobalAliases.Dump(), p.Stdout.IsTTY())
-		if err != nil {
-			return err
-		}
-		_, err = p.Stdout.Writeln(b)
-		return err
-
-	}
-
-	p.Stdout.SetDataType(types.Null)
-
-	s, _ := p.Parameters.String(0)
-	eq, _ := p.Parameters.String(1)
-
-	if !rxAlias.MatchString(s) && len(eq) > 0 && eq[0] != '=' {
-		return errors.New("invalid syntax. Expecting `alias new_name=original_name parameter1 parameter2 ...`")
-	}
-
-	var (
-		split  = rxAlias.FindStringSubmatch(s)
-		name   string
-		params []string
-	)
-
-	if len(split) == 0 {
-		name = s
-		params = p.Parameters.StringArray()[1:]
-		switch {
-		case len(params) == 0:
-			return fmt.Errorf("no command supplied")
-		case len(params[0]) == 1 && params[0] == "=":
-			params = params[1:]
-		case len(params[0]) > 0 && params[0][0] == '=':
-			params[0] = params[0][1:]
-		default:
-			return fmt.Errorf("unknown error. Please check syntax follows `alias new_name=original_name parameter1 parameter2 ...`")
-		}
-
-	} else {
-		name = split[1]
-		params = append([]string{split[2]}, p.Parameters.StringArray()[1:]...)
-	}
-
-	if len(params) == 0 {
-		return fmt.Errorf("no command supplied")
-	}
-
-	if params[0] == "" && len(params) > 0 {
-		params = params[1:]
-	}
-
-	if len(params) == 0 || params[0] == "" {
-		return fmt.Errorf("no command supplied")
-	}
-
-	lang.GlobalAliases.Add(name, params, p.FileRef)
-	return nil
-}
-
-func cmdUnalias(p *lang.Process) error {
-	p.Stdout.SetDataType(types.Null)
-
-	for _, name := range p.Parameters.StringArray() {
-		err := lang.GlobalAliases.Delete(name)
-		if err != nil {
-			return err
-		}
-	}
-	return nil
-}
-
 func cmdFunc(p *lang.Process) error {
 	var dtParamsT []lang.MurexFuncParam
 
