@@ -11,7 +11,7 @@ func index(p *lang.Process, params []string) error {
 		return err
 	}
 
-	marshaller := func(iface interface{}) ([]byte, error) {
+	marshaller := func(iface any) ([]byte, error) {
 		return json.Marshal(iface, p.Stdout.IsTTY())
 	}
 
