@@ -4,8 +4,10 @@ import (
 	"bufio"
 	"bytes"
 	"context"
+	"fmt"
 
 	"github.com/lmorg/murex/lang/stdio"
+	"github.com/lmorg/murex/lang/types"
 )
 
 func readArray(ctx context.Context, read stdio.Io, callback func([]byte)) error {
@@ -20,5 +22,10 @@ func readArray(ctx context.Context, read stdio.Io, callback func([]byte)) error
 		}
 	}
 
-	return scanner.Err()
+	err := scanner.Err()
+	if err != nil {
+		return fmt.Errorf("error while reading a %s array: %s", types.String, err.Error())
+	}
+
+	return nil
 }
