@@ -11,7 +11,7 @@ import (
 	"github.com/lmorg/murex/utils"
 )
 
-func marshal(_ *lang.Process, iface interface{}) (b []byte, err error) {
+func marshal(_ *lang.Process, iface any) (b []byte, err error) {
 	switch v := iface.(type) {
 	case string:
 		b = []byte(v)
@@ -23,7 +23,7 @@ func marshal(_ *lang.Process, iface interface{}) (b []byte, err error) {
 		}
 		return
 
-	case []interface{}:
+	case []any:
 		for i := range v {
 			b = append(b, []byte(fmt.Sprintln(v[i]))...)
 		}
@@ -35,25 +35,25 @@ func marshal(_ *lang.Process, iface interface{}) (b []byte, err error) {
 		}
 		return
 
-	case map[string]interface{}:
+	case map[string]any:
 		for s := range v {
 			b = append(b, []byte(fmt.Sprintf("%s: %s%s", s, fmt.Sprint(v[s]), utils.NewLineString))...)
 		}
 		return
 
-	case map[interface{}]interface{}:
+	case map[any]any:
 		for s := range v {
 			b = append(b, []byte(fmt.Sprintf("%s: %s%s", fmt.Sprint(s), fmt.Sprint(v[s]), utils.NewLineString))...)
 		}
 		return
 
-	case map[interface{}]string:
+	case map[any]string:
 		for s := range v {
 			b = append(b, []byte(fmt.Sprintf("%s: %s%s", fmt.Sprint(s), v[s], utils.NewLineString))...)
 		}
 		return
 
-	case interface{}:
+	case any:
 		return []byte(fmt.Sprintln(iface)), nil
 
 	default:
@@ -62,7 +62,7 @@ func marshal(_ *lang.Process, iface interface{}) (b []byte, err error) {
 	}
 }
 
-func unmarshal(p *lang.Process) (interface{}, error) {
+func unmarshal(p *lang.Process) (any, error) {
 	s := make([]string, 0)
 
 	scanner := bufio.NewScanner(p.Stdin)
