@@ -22,9 +22,9 @@ export default navbar([
       },
     ],
   },
-  { text: "Install", link: "install.html", icon: "download" },
-  { text: "Tour", link: "tour.html", icon: "plane-departure" },
-  { text: "Cheat Sheet", link: "user-guide/rosetta-stone.html", icon: "table" },
+  { text: "Install", link: "/install", icon: "download" },
+  { text: "Tour", link: "/tour", icon: "plane-departure" },
+  { text: "Cheat Sheet", link: "/user-guide/rosetta-stone.html", icon: "table" },
   { text: "Discuss", link: "https://github.com/lmorg/murex/discussions", icon: "comment" },
   { text: "Contribute", link: "/contributing", icon: "handshake-angle" },
   //"/contributing",
