@@ -353,27 +353,6 @@ func TestExpNotRegexp(t *testing.T) {
 // https://github.com/lmorg/murex/issues/831
 func TestExprEquBugFixes(t *testing.T) {
 	tests := []test.MurexTest{
-		{
-			Block:   `foobar == foobar`,
-			Stderr:  `Error`,
-			ExitNum: 1,
-		},
-		{
-			Block:   `"foobar" == foobar`,
-			Stderr:  `Error`,
-			ExitNum: 1,
-		},
-		{
-			Block:   `foobar == "foobar"`,
-			Stderr:  `Error`,
-			ExitNum: 1,
-		},
-		{
-			Block:   `"foobar" == "foobar"`,
-			Stdout:  `true`,
-			ExitNum: 0,
-		},
-		/////
 		{
 			Block:   `%[z y x] == %[z y x]`,
 			Stdout:  `true`,
