@@ -31,10 +31,10 @@ func TestParseBlock(t *testing.T) {
 			Block:  "out 1\nout 2\nout 3\nout 4\nout 5\n\n",
 			Stdout: "1\n2\n3\n4\n5\n",
 		},
-		{
+		/*{
 			Block:  `${err 1|err 2|err 3|err 4|err 5} ? msort`,
 			Stdout: "1\n2\n3\n4\n5\n",
-		},
+		},*/
 		{
 			Block:  "out:1\nout:2\nout:3\nout:4\nout:5",
 			Stdout: "1\n2\n3\n4\n5\n",
@@ -167,17 +167,6 @@ func TestParseBlockEscapedCrLf(t *testing.T) {
 	test.RunMurexTests(tests, t)
 }
 
-func TestParseBlockEqu(t *testing.T) {
-	tests := []test.MurexTest{
-		{
-			Block:  `= true`,
-			Stdout: `true`,
-		},
-	}
-
-	test.RunMurexTests(tests, t)
-}
-
 func TestParseBlockPipeOverwriteFile1(t *testing.T) {
 	filename := fmt.Sprintf("%s-%d.testfile", t.Name(), time.Now().UnixNano())
 	tests := []test.MurexTest{
@@ -207,7 +196,7 @@ func TestParseBlockPipeAppendFile1(t *testing.T) {
 	tests := []test.MurexTest{
 		{
 			Block:  fmt.Sprintf(`%%(%s) >> %s; %%(%s) >> %s; open %s; rm %s`, filename, filename, filename, filename, filename, filename),
-			Stdout: filename + filename,
+			Stdout: fmt.Sprintf(`%s%s`, filename, filename),
 		},
 	}
 
@@ -219,11 +208,12 @@ func TestParseBlockPipeAppendFile2(t *testing.T) {
 	tests := []test.MurexTest{
 		{
 			Block:  fmt.Sprintf(`echo %s >> %s; echo %s >> %s; open %s; rm %s`, filename, filename, filename, filename, filename, filename),
-			Stdout: fmt.Sprintf("%s\n%s\n", filename, filename),
+			Stdout: fmt.Sprintf("^%s\n%s\n$", filename, filename),
+			Stderr: `^warning:`,
 		},
 	}
 
-	test.RunMurexTests(tests, t)
+	test.RunMurexTestsRx(tests, t)
 }
 
 func TestParseBlockLogicOperators(t *testing.T) {
@@ -376,3 +366,62 @@ func TestParseBlockArrayPanicBugFix(t *testing.T) {
 
 	test.RunMurexTestsRx(tests, t)
 }
+
+func TestAlterOp(t *testing.T) {
+	tests := []test.MurexTest{
+		{
+			Block:  `tout json %{a:1, b:2, c:3} ~> %{b:4}`,
+			Stdout: `{"a":1,"b":4,"c":3}`,
+		},
+	}
+
+	test.RunMurexTests(tests, t)
+}
+
+func TestIssue854(t *testing.T) {
+	tests := []test.MurexTest{
+		{
+			Block:   `TestIssue854_alksdlsdkfjsldfkjsldfkjsldfkjsldkfj== TestIssue854_alksdlsdkfjsldfkjsldfkjsldfkjsldkfj`,
+			Stderr:  `cannot EqualTo`,
+			ExitNum: 1,
+		},
+		{
+			Block:   `"TestIssue854_alksdlsdkfjsldfkjsldfkjsldfkjsldkfj"== TestIssue854_alksdlsdkfjsldfkjsldfkjsldfkjsldkfj`,
+			Stderr:  `cannot EqualTo`,
+			ExitNum: 1,
+		},
+		{
+			Block:   `TestIssue854_alksdlsdkfjsldfkjsldfkjsldfkjsldkfj== "TestIssue854_alksdlsdkfjsldfkjsldfkjsldfkjsldkfj"`,
+			Stderr:  `cannot EqualTo`,
+			ExitNum: 1,
+		},
+		{
+			Block:   `"TestIssue854_alksdlsdkfjsldfkjsldfkjsldfkjsldkfj"== "TestIssue854_alksdlsdkfjsldfkjsldfkjsldfkjsldkfj"`,
+			Stdout:  `true`,
+			ExitNum: 0,
+		},
+		/////
+		{
+			Block:   `TestIssue854_alksdlsdkfjsldfkjsldfkjsldfkjsldkfj == TestIssue854_alksdlsdkfjsldfkjsldfkjsldfkjsldkfj`,
+			Stderr:  `cannot EqualTo`,
+			ExitNum: 1,
+		},
+		{
+			Block:   `"TestIssue854_alksdlsdkfjsldfkjsldfkjsldfkjsldkfj" == TestIssue854_alksdlsdkfjsldfkjsldfkjsldfkjsldkfj`,
+			Stderr:  `cannot EqualTo`,
+			ExitNum: 1,
+		},
+		{
+			Block:   `TestIssue854_alksdlsdkfjsldfkjsldfkjsldfkjsldkfj == "TestIssue854_alksdlsdkfjsldfkjsldfkjsldfkjsldkfj"`,
+			Stderr:  `cannot EqualTo`,
+			ExitNum: 1,
+		},
+		{
+			Block:   `"TestIssue854_alksdlsdkfjsldfkjsldfkjsldfkjsldkfj" == "TestIssue854_alksdlsdkfjsldfkjsldfkjsldfkjsldkfj"`,
+			Stdout:  `true`,
+			ExitNum: 0,
+		},
+	}
+
+	test.RunMurexTestsRx(tests, t)
+}
