@@ -22,3 +22,14 @@ func TestName(t *testing.T) {
 		t.Errorf("Set and/or String failed. Didn't return 'foobar'")
 	}
 }
+
+func TestNameSetRune(t *testing.T) {
+	count.Tests(t, 2)
+
+	name := new(process.Name)
+
+	name.SetRune([]rune{'f', 'o', 'o', 'b', 'a', 'r'})
+	if name.String() != "foobar" {
+		t.Errorf("SetRune and/or String failed. Didn't return 'foobar'")
+	}
+}
