@@ -7,20 +7,25 @@ import (
 	"github.com/lmorg/murex/config/defaults"
 	"github.com/lmorg/murex/lang"
 	"github.com/lmorg/murex/lang/types"
-	"github.com/lmorg/murex/shell"
 	"github.com/lmorg/murex/test"
 )
 
-/* Bug fix:
+/*
+	Bug fix:
+
 » function abc { config: set proc echo true ; out: testing; a: [1..3] }
 » abc
 panic: interface conversion: interface {} is string, not bool
 
 goroutine 922 [running]:
 github.com/lmorg/murex/lang.executeProcess(0xc0001082b0)
-		/Users/laurencemorgan/go/src/github.com/lmorg/murex/lang/process.go:196 +0x158d
+
+	/Users/laurencemorgan/go/src/github.com/lmorg/murex/lang/process.go:196 +0x158d
+
 created by github.com/lmorg/murex/lang.runModeNormal
-		/Users/laurencemorgan/go/src/github.com/lmorg/murex/lang/interpreter.go:180 +0x7e
+
+	/Users/laurencemorgan/go/src/github.com/lmorg/murex/lang/interpreter.go:180 +0x7e
+
 murex-dev»
 */
 func TestBugFix(t *testing.T) {
@@ -31,7 +36,6 @@ func TestBugFix(t *testing.T) {
 	})
 	lang.InitEnv()
 	defaults.Config(lang.ShellProcess.Config, false)
-	shell.SignalHandler(false)
 
 	tests := []test.MurexTest{
 		{
