@@ -8,7 +8,7 @@ import (
 )
 
 func TestRunModeStringer(t *testing.T) {
-	count.Tests(t, 5)
+	count.Tests(t, 16)
 
 	defer func() {
 		if r := recover(); r != nil {
@@ -18,13 +18,25 @@ func TestRunModeStringer(t *testing.T) {
 	}()
 
 	t.Log(runmode.Normal.String())
-	t.Log(runmode.Evil.String())
+
+	t.Log(runmode.BlockUnsafe.String())
+	t.Log(runmode.FunctionUnsafe.String())
+	t.Log(runmode.ModuleUnsafe.String())
+
 	t.Log(runmode.BlockTry.String())
 	t.Log(runmode.BlockTryPipe.String())
-	/*t.Log(runmode.FunctionTry.String())
+	t.Log(runmode.BlockTryErr.String())
+	t.Log(runmode.BlockTryPipeErr.String())
+
+	t.Log(runmode.FunctionTry.String())
 	t.Log(runmode.FunctionTryPipe.String())
+	t.Log(runmode.FunctionTryErr.String())
+	t.Log(runmode.FunctionTryPipeErr.String())
+
 	t.Log(runmode.ModuleTry.String())
-	t.Log(runmode.ModuleTryPipe.String())*/
+	t.Log(runmode.ModuleTryPipe.String())
+	t.Log(runmode.ModuleTryErr.String())
+	t.Log(runmode.ModuleTryPipeErr.String())
 }
 
 func TestRunModeIsStrict(t *testing.T) {
@@ -33,13 +45,25 @@ func TestRunModeIsStrict(t *testing.T) {
 		Strict  bool
 	}{
 		{runmode.Normal, false},
-		{runmode.Evil, false},
+
+		{runmode.BlockUnsafe, false},
+		{runmode.FunctionUnsafe, false},
+		{runmode.ModuleUnsafe, false},
+
 		{runmode.BlockTry, true},
 		{runmode.BlockTryPipe, true},
-		/*{runmode.FunctionTry, true},
+		{runmode.BlockTryErr, true},
+		{runmode.BlockTryPipeErr, true},
+
+		{runmode.FunctionTry, true},
 		{runmode.FunctionTryPipe, true},
+		{runmode.FunctionTryErr, true},
+		{runmode.FunctionTryPipeErr, true},
+
 		{runmode.ModuleTry, true},
-		{runmode.ModuleTryPipe, true},*/
+		{runmode.ModuleTryPipe, true},
+		{runmode.ModuleTryErr, true},
+		{runmode.ModuleTryPipeErr, true},
 	}
 
 	count.Tests(t, len(tests))
