@@ -4,7 +4,7 @@ import (
 	"strings"
 
 	"github.com/lmorg/murex/utils/ansi"
-	"github.com/lmorg/murex/utils/readline"
+	"github.com/lmorg/readline/v4"
 )
 
 func previewError(err error, size *readline.PreviewSizeT) ([]string, int, error) {
