@@ -1,9 +1,10 @@
-//go:build js || windows || plan9
-// +build js windows plan9
+//go:build js || windows || plan9 || tinygo
+// +build js windows plan9 tinygo
 
 package session
 
 import (
+	"os"
 	"runtime"
 
 	"github.com/lmorg/murex/debug"
@@ -18,3 +19,7 @@ func UnixIsSession() bool { return false }
 func UnixCreateSession() {
 	debug.Logf("!!! UnixCreateSession is not supported on %s", runtime.GOOS)
 }
+
+func UnixTTY() *os.File {
+	return os.Stdin
+}
