@@ -4,8 +4,10 @@
 package man
 
 import (
+	"bufio"
 	"bytes"
 	"fmt"
+	"io"
 	"regexp"
 	"strings"
 
@@ -18,7 +20,7 @@ import (
 	"github.com/lmorg/murex/utils/rmbs"
 )
 
-func parseDescriptions(command string, fMap *map[string]string) {
+func GetManPage(command string, width int) stdio.Io {
 	fork := lang.ShellProcess.Fork(lang.F_FUNCTION | lang.F_NO_STDIN | lang.F_CREATE_STDOUT | lang.F_NO_STDERR)
 	fork.Name.Set("(man)")
 	err := fork.Variables.Set(fork.Process, "command", command, types.String)
@@ -26,17 +28,23 @@ func parseDescriptions(command string, fMap *map[string]string) {
 		if debug.Enabled {
 			panic(err)
 		}
-		return
+		return nil
 	}
-	_, err = fork.Execute(manBlock)
+
+	_, err = fork.Execute(ManPageExecBlock(width))
 	if err != nil {
 		if debug.Enabled {
 			panic(err)
 		}
-		return
+		return nil
 	}
 
-	parseDescriptionsLines(fork.Stdout, fMap)
+	return fork.Stdout
+}
+
+func parseDescriptions(command string, fMap *map[string]string) {
+	stdout := GetManPage(command, 1000)
+	parseDescriptionsLines(stdout, fMap)
 }
 
 var rxHeading = regexp.MustCompile(`^[A-Z]+$`)
@@ -48,10 +56,16 @@ var validSections = []string{
 	"EXPRESSION", // required for `find` on GNU
 }
 
-func parseDescriptionsLines(io stdio.Io, fMap *map[string]string) {
+func parseDescriptionsLines(r io.Reader, fMap *map[string]string) {
 	var pl *parsedLineT
 	var section string
-	err := io.ReadLine(func(b []byte) {
+
+	scanner := bufio.NewScanner(r)
+
+	for scanner.Scan() {
+		b := scanner.Bytes()
+		//b := append(scanner.Bytes(), utils.NewLineByte...)
+
 		b = []byte(rmbs.Remove(string(b)))
 		b = utils.CrLfTrim(b)
 
@@ -61,7 +75,7 @@ func parseDescriptionsLines(io stdio.Io, fMap *map[string]string) {
 		}
 
 		if !lists.Match(validSections, section) {
-			return
+			continue
 		}
 
 		ws := countWhiteSpace(b)
@@ -78,7 +92,7 @@ func parseDescriptionsLines(io stdio.Io, fMap *map[string]string) {
 			pl = parseLineFlags(b[ws:])
 
 		case pl == nil:
-			return
+			continue
 
 		case pl.Description != "" && len(pl.Description) < 30 && ws >= 8: // kludge for `find` style flags
 			pl.Example += " " + pl.Description
@@ -96,12 +110,9 @@ func parseDescriptionsLines(io stdio.Io, fMap *map[string]string) {
 			updateFlagMap(pl, fMap)
 			pl = nil
 		}
-	})
-	if err != nil {
-		if debug.Enabled {
-			panic(err)
-		}
-		return
+	}
+	if err := scanner.Err(); err != nil && debug.Enabled {
+		panic(err)
 	}
 }
 
@@ -135,7 +146,6 @@ func countWhiteSpace(b []byte) int {
 }
 
 var (
-	//rxLineMatchFlag = regexp.MustCompile(`^-[-_a-zA-Z0-9]+`)
 	rxLineMatchFlag = regexp.MustCompile(`^-[-_a-zA-Z0-9]+`)
 	rxExampleCaps   = regexp.MustCompile(`^[A-Z]+([\t, ]|$)`)
 )
@@ -154,6 +164,7 @@ func parseLineFlags(b []byte) *parsedLineT {
 
 	for {
 	start:
+		//fmt.Println(json.LazyLoggingPretty(*pl), "-->"+string(b)+"<--")
 		if pl.Position == len(b) {
 			return pl
 		}
@@ -161,7 +172,7 @@ func parseLineFlags(b []byte) *parsedLineT {
 		switch b[pl.Position] {
 		case ',':
 			pl.Position += countWhiteSpace(b[pl.Position+1:]) + 1
-			fallthrough
+			//fallthrough
 
 		case '-':
 			match := rxLineMatchFlag.Find(b[pl.Position:])
@@ -174,25 +185,41 @@ func parseLineFlags(b []byte) *parsedLineT {
 			i := parseFlag(b[pl.Position:], pl)
 			pl.Position += i
 
-		case '=', '[':
+		case '=', '[', '<':
 			start := pl.Position
-			var group bool
+			group := true
+			grpC := b[pl.Position]
 			for ; pl.Position < len(b); pl.Position++ {
 				switch b[pl.Position] {
-				case '[':
-					group = true
+				case '[', '<':
+					switch grpC {
+					case '=':
+						grpC = b[pl.Position]
+					}
 				case ']':
-					group = false
+					switch grpC {
+					case '[':
+						group = false
+					}
+				case '>':
+					switch grpC {
+					case '<':
+						group = false
+					}
 				case ' ', '\t', ',':
-					if group {
+					if grpC == '[' || grpC == '<' {
 						continue
 					}
-					pl.Example = string(b[start:pl.Position])
-					goto start
+					group = false
+				}
+				if !group {
+					break
 				}
 			}
+			pl.Example = string(b[start:pl.Position])
+			goto start
 
-		case ' ':
+		case ' ', '\t':
 			example := rxExampleCaps.Find(b[pl.Position+1:])
 			switch {
 			case len(example) == 0:
@@ -217,37 +244,61 @@ func parseLineFlags(b []byte) *parsedLineT {
 }
 
 func parseFlag(b []byte, pl *parsedLineT) int {
-	var bracket, split bool
+	//fmt.Println("parseFlag", string(b))
+	var (
+		split   bool
+		bracket byte = 0
+	)
+
 	for i, c := range b {
+		//fmt.Printf("i==%d c=='%s' bracket=%d\n", i, string(c), bracket)
 		switch {
 		case isValidFlagChar(c):
 			continue
 
-		case c == '[':
+		case c == '[', c == '<':
 			switch {
-			case bracket:
+			case bracket == c:
 				return 0
 			case i+1 == len(b):
 				return 0
 			case b[i+1] == '=':
 				splitFlags(b[:i], split, pl)
 				return i
-			case isValidFlagChar(b[i+1]):
-				bracket = true
+			//case isValidFlagChar(b[i+1]), b[i+1] == '=', b[i+1] == '<':
+			//	bracket = true
+			case bracket != 0:
+				continue
 			default:
-				return 0
+				//	return 0
+				bracket = c
 			}
 
 		case c == ']':
-			if !bracket {
+			switch bracket {
+			case 0:
 				return 0
+			case '[':
+				bracket = 0
+				split = true
+			default:
+				continue
+			}
+
+		case c == '>':
+			switch bracket {
+			case 0:
+				return 0
+			case '<':
+				bracket = 0
+				split = true
+			default:
+				continue
 			}
-			bracket = false
-			split = true
 
 		default:
-			if bracket {
-				return 0
+			if bracket != 0 {
+				continue
 			}
 			splitFlags(b[:i], split, pl)
 			return i
